#[repr(C)]pub struct CurveSegment {
pub x0: f32,
pub x1: f32,
pub Type: i32,
pub Params: [f64; 10],
pub nGridPoints: u32,
pub SampledPoints: *mut f32,
}Expand description
This describes a curve segment.
For a table of supported types, see the manual. User can increase the number of available types by using a proper plug-in. Parametric segments allow 10 parameters at most
Fields
x0: f32x1: f32Type: i32Params: [f64; 10]nGridPoints: u32SampledPoints: *mut f32Trait Implementations
Sourceimpl Clone for CurveSegment
impl Clone for CurveSegment
Sourcefn clone(&self) -> CurveSegment
fn clone(&self) -> CurveSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CurveSegment
Sourceimpl Debug for CurveSegment
impl Debug for CurveSegment